@@ -20,7 +20,7 @@
 #include "musicalbum.h"
 #include "musicaudiotrack.h"
 #include "databaseinterface.h"
-#include "alltracksmodel.h"
+#include "models/alltracksmodel.h"
 #include "modeltest.h"
 
 #include <QObject>
@@ -504,6 +504,62 @@ private Q_SLOTS:
 
         QCOMPARE(tracksModel.rowCount(), 0);
     }
+
+    void addTracksListTwice()
+    {
+        DatabaseInterface musicDb;
+        AllTracksModel tracksModel;
+        ModelTest testModel(&tracksModel);
+
+        connect(&musicDb, &DatabaseInterface::tracksAdded,
+                &tracksModel, &AllTracksModel::tracksAdded);
+        connect(&musicDb, &DatabaseInterface::trackModified,
+                &tracksModel, &AllTracksModel::trackModified);
+        connect(&musicDb, &DatabaseInterface::trackRemoved,
+                &tracksModel, &AllTracksModel::trackRemoved);
+
+        musicDb.init(QStringLiteral("testDb"));
+
+        QSignalSpy beginInsertRowsSpy(&tracksModel, &AllTracksModel::rowsAboutToBeInserted);
+        QSignalSpy endInsertRowsSpy(&tracksModel, &AllTracksModel::rowsInserted);
+        QSignalSpy beginRemoveRowsSpy(&tracksModel, &AllTracksModel::rowsAboutToBeRemoved);
+        QSignalSpy endRemoveRowsSpy(&tracksModel, &AllTracksModel::rowsRemoved);
+        QSignalSpy dataChangedSpy(&tracksModel, &AllTracksModel::dataChanged);
+
+        QCOMPARE(beginInsertRowsSpy.count(), 0);
+        QCOMPARE(endInsertRowsSpy.count(), 0);
+        QCOMPARE(beginRemoveRowsSpy.count(), 0);
+        QCOMPARE(endRemoveRowsSpy.count(), 0);
+        QCOMPARE(dataChangedSpy.count(), 0);
+
+        musicDb.insertTracksList(mNewTracks, mNewCovers, QStringLiteral("autoTest"));
+
+        QCOMPARE(beginInsertRowsSpy.count(), 1);
+        QCOMPARE(endInsertRowsSpy.count(), 1);
+        QCOMPARE(beginRemoveRowsSpy.count(), 0);
+        QCOMPARE(endRemoveRowsSpy.count(), 0);
+        QCOMPARE(dataChangedSpy.count(), 0);
+
+        QCOMPARE(tracksModel.rowCount(), 18);
+
+        auto newTrack = MusicAudioTrack{true, QStringLiteral("$19"), QStringLiteral("0"), QStringLiteral("track19"),
+                QStringLiteral("artist1"), QStringLiteral("album1"), QStringLiteral("Various Artists"),
+                1, 1, QTime::fromMSecsSinceStartOfDay(19), {QUrl::fromLocalFile(QStringLiteral("/$19"))},
+                {QUrl::fromLocalFile(QStringLiteral("file://image$19"))}, 5, true};
+
+        auto newTracks = QList<MusicAudioTrack>();
+        newTracks.push_back(newTrack);
+
+        musicDb.insertTracksList(newTracks, mNewCovers, QStringLiteral("autoTest"));
+
+        QCOMPARE(beginInsertRowsSpy.count(), 2);
+        QCOMPARE(endInsertRowsSpy.count(), 2);
+        QCOMPARE(beginRemoveRowsSpy.count(), 0);
+        QCOMPARE(endRemoveRowsSpy.count(), 0);
+        QCOMPARE(dataChangedSpy.count(), 0);
+
+        QCOMPARE(tracksModel.rowCount(), 19);
+    }
 };
 
 QTEST_GUILESS_MAIN(AllTracksModelTests)
