@@ -22,16 +22,37 @@
 
 #include "musicaudiotrack.h"
 
-#include <KFileMetaData/ExtractorCollection>
-
 #include <QUrl>
 #include <QMimeDatabase>
+#include <QMetaObject>
+
+namespace KFileMetaData {
+
+class ExtractorCollection;
+
+}
 
 namespace ElisaUtils {
 
+Q_NAMESPACE
+
 MusicAudioTrack scanOneFile(const QUrl &scanFile, const QMimeDatabase &mimeDatabase,
                             const KFileMetaData::ExtractorCollection &allExtractors);
 
+enum PlayListEnqueueMode {
+    AppendPlayList,
+    ReplacePlayList,
+};
+
+Q_ENUM_NS(PlayListEnqueueMode)
+
+enum PlayListEnqueueTriggerPlay {
+    DoNotTriggerPlay,
+    TriggerPlay,
+};
+
+Q_ENUM_NS(PlayListEnqueueTriggerPlay)
+
 }
 
 #endif // ELISAUTILS_H
