@@ -43,18 +43,24 @@
 #include "manageheaderbar.h"
 #include "manageaudioplayer.h"
 #include "musicstatistics.h"
-#include "allalbumsmodel.h"
-#include "albummodel.h"
-#include "allartistsmodel.h"
 #include "musicaudiotrack.h"
 #include "musiclistenersmanager.h"
-#include "albumfilterproxymodel.h"
+#include "models/allalbumsmodel.h"
+#include "models/albummodel.h"
+#include "models/allartistsmodel.h"
+#include "models/alltracksmodel.h"
+#include "models/allalbumsproxymodel.h"
+#include "models/alltracksproxymodel.h"
+#include "models/allartistsproxymodel.h"
+#include "models/singleartistproxymodel.h"
+#include "models/singlealbumproxymodel.h"
 #include "elisaapplication.h"
 #include "audiowrapper.h"
-#include "alltracksmodel.h"
 #include "notificationitem.h"
 #include "topnotificationmanager.h"
 #include "elisa_settings.h"
+#include "trackdatahelper.h"
+#include "elisautils.h"
 
 #if defined Qt5DBus_FOUND && Qt5DBus_FOUND
 #include "mpris2/mpris2.h"
@@ -89,6 +95,7 @@
 #include <QQmlFileSelector>
 #include <QQmlDebuggingEnabler>
 #include <QQmlContext>
+#include <QScreen>
 
 #if defined Qt5AndroidExtras_FOUND && Qt5AndroidExtras_FOUND
 #include <QAndroidJniObject>
@@ -105,6 +112,8 @@ int __attribute__((visibility("default"))) main(int argc, char *argv[])
 int main(int argc, char *argv[])
 #endif
 {
+    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+
     qputenv("QT_GSTREAMER_USE_PLAYBIN_VOLUME", "true");
 
     QApplication app(argc, argv);
@@ -145,25 +154,26 @@ int main(int argc, char *argv[])
     qmlRegisterType<ManageAudioPlayer>("org.kde.elisa", 1, 0, "ManageAudioPlayer");
     qmlRegisterType<MusicStatistics>("org.kde.elisa", 1, 0, "MusicStatistics");
     qmlRegisterType<ProgressIndicator>("org.kde.elisa", 1, 0, "ProgressIndicator");
-    qmlRegisterType<AllAlbumsModel>("org.kde.elisa", 1, 0, "AllAlbumsModel");
-    qmlRegisterType<AllArtistsModel>("org.kde.elisa", 1, 0, "AllArtistsModel");
-    qmlRegisterType<AlbumModel>("org.kde.elisa", 1, 0, "AlbumModel");
-    qmlRegisterType<AllTracksModel>("org.kde.elisa", 1, 0, "AllTracksModel");
     qmlRegisterType<MusicListenersManager>("org.kde.elisa", 1, 0, "MusicListenersManager");
-    qmlRegisterType<QSortFilterProxyModel>("org.kde.elisa", 1, 0, "SortFilterProxyModel");
-    qmlRegisterType<AlbumFilterProxyModel>("org.kde.elisa", 1, 0, "AlbumFilterProxyModel");
+    qmlRegisterType<AllAlbumsProxyModel>("org.kde.elisa", 1, 0, "AllAlbumsProxyModel");
+    qmlRegisterType<AllArtistsProxyModel>("org.kde.elisa", 1, 0, "AllArtistsProxyModel");
+    qmlRegisterType<AllTracksProxyModel>("org.kde.elisa", 1, 0, "AllTracksProxyModel");
+    qmlRegisterType<SingleAlbumProxyModel>("org.kde.elisa", 1, 0, "SingleAlbumProxyModel");
+    qmlRegisterType<SingleArtistProxyModel>("org.kde.elisa", 1, 0, "SingleArtistProxyModel");
     qmlRegisterType<AudioWrapper>("org.kde.elisa", 1, 0, "AudioWrapper");
     qmlRegisterType<TopNotificationManager>("org.kde.elisa", 1, 0, "TopNotificationManager");
+    qmlRegisterType<TrackDataHelper>("org.kde.elisa", 1, 0, "TrackDataHelper");
 
 #if defined Qt5DBus_FOUND && Qt5DBus_FOUND
     qmlRegisterType<Mpris2>("org.kde.elisa", 1, 0, "Mpris2");
     qRegisterMetaType<MediaPlayer2Player*>();
 #endif
 
-    qRegisterMetaType<QAbstractItemModel*>();
+    qRegisterMetaType<AbstractMediaProxyModel*>();
     qRegisterMetaType<QHash<QString,QUrl>>("QHash<QString,QUrl>");
     qRegisterMetaType<QList<MusicAudioTrack>>("QList<MusicAudioTrack>");
     qRegisterMetaType<QList<MusicAudioTrack>>("QVector<MusicAudioTrack>");
+    qRegisterMetaType<QList<MusicAlbum>>("QList<MusicAlbum>");
     qRegisterMetaType<QVector<qulonglong>>("QVector<qulonglong>");
     qRegisterMetaType<QHash<qulonglong,int>>("QHash<qulonglong,int>");
     qRegisterMetaType<MusicAlbum>("MusicAlbum");
@@ -172,13 +182,15 @@ int main(int argc, char *argv[])
     qRegisterMetaType<QAction*>();
     qRegisterMetaType<NotificationItem>("NotificationItem");
     qRegisterMetaType<QMap<QString,int>>("QMap<QString,int>");
+    qRegisterMetaType<ElisaUtils::PlayListEnqueueMode>("ElisaUtils::PlayListEnqueueMode");
+    qRegisterMetaType<ElisaUtils::PlayListEnqueueTriggerPlay>("ElisaUtils::PlayListEnqueueTriggerPlay");
     qmlRegisterUncreatableType<ElisaApplication>("org.kde.elisa", 1, 0, "ElisaApplication", QStringLiteral("only one and done in c++"));
 
     qRegisterMetaTypeStreamOperators<ManageMediaPlayerControl::PlayerState>("PlayListControler::PlayerState");
 
     KAboutData aboutData( QStringLiteral("elisa"),
                           i18n("Elisa"),
-                          QStringLiteral("0.0.81"),
+                          QStringLiteral("0.1"),
                           i18n("A Simple Music Player written with KDE Frameworks"),
                           KAboutLicense::LGPL_V3,
                           i18n("(c) 2015-2017, Matthieu Gallien &lt;mgallien@mgallien.fr&gt;"));
@@ -230,9 +242,6 @@ int main(int argc, char *argv[])
     Elisa::ElisaConfiguration::self()->load();
     Elisa::ElisaConfiguration::self()->save();
 
-    MusicListenersManager myMusicManager;
-    myMusicManager.setElisaApplication(&myApp);
-
     QQmlApplicationEngine engine;
     engine.addImportPath(QStringLiteral("qrc:/imports"));
     QQmlFileSelector selector(&engine);
@@ -245,7 +254,7 @@ int main(int argc, char *argv[])
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
     engine.rootContext()->setContextProperty(QStringLiteral("elisa"), &myApp);
-    engine.rootContext()->setContextProperty(QStringLiteral("allListeners"), &myMusicManager);
+    engine.rootContext()->setContextProperty(QStringLiteral("logicalDpi"), QGuiApplication::primaryScreen()->logicalDotsPerInch());
 
     engine.load(QUrl(QStringLiteral("qrc:/qml/ElisaMainWindow.qml")));
 
