@@ -59,6 +59,7 @@ MediaPlayList::MediaPlayList(QObject *parent) : QAbstractListModel(parent), d(ne
 {
     connect(&d->mLoadPlaylist, &QMediaPlaylist::loaded, this, &MediaPlayList::loadPlayListLoaded);
     connect(&d->mLoadPlaylist, &QMediaPlaylist::loadFailed, this, &MediaPlayList::loadPlayListLoadFailed);
+    seedRandomGenerator(QTime::currentTime().msec());
 }
 
 MediaPlayList::~MediaPlayList()
@@ -257,7 +258,6 @@ QVariant MediaPlayList::data(const QModelIndex &index, int role) const
             result = QVariant::fromValue(d->mTrackData[index.row()]);
             break;
         }
-
     } else {
         switch(role)
         {
@@ -299,6 +299,7 @@ QVariant MediaPlayList::data(const QModelIndex &index, int role) const
         case ColumnsRoles::DiscNumberRole:
             break;
         case ColumnsRoles::IsSingleDiscAlbumHeader:
+            result = false;
             break;
         case ColumnsRoles::MilliSecondsDurationRole:
             break;
@@ -323,6 +324,10 @@ QVariant MediaPlayList::data(const QModelIndex &index, int role) const
         case ColumnsRoles::ShadowForImageRole:
             result = false;
             break;
+        case ColumnsRoles::TrackDataRole:
+            MusicAudioTrack emptyTrack;
+            result = QVariant::fromValue(emptyTrack);
+            break;
         }
     }
 
@@ -420,75 +425,6 @@ bool MediaPlayList::removeRows(int row, int count, const QModelIndex &parent)
     return false;
 }
 
-void MediaPlayList::enqueue(qulonglong newTrackId)
-{
-    enqueue(MediaPlayListEntry(newTrackId));
-}
-
-void MediaPlayList::enqueue(const MusicAudioTrack &newTrack)
-{
-    enqueue(MediaPlayListEntry(newTrack), newTrack);
-}
-
-void MediaPlayList::clearAndEnqueue(qulonglong newTrackId)
-{
-    clearPlayList();
-    enqueue(MediaPlayListEntry(newTrackId));
-}
-
-void MediaPlayList::clearAndEnqueue(const MusicAudioTrack &newTrack)
-{
-    clearPlayList();
-    enqueue(newTrack);
-}
-
-void MediaPlayList::enqueue(const MediaPlayListEntry &newEntry, const MusicAudioTrack &audioTrack)
-{
-    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size());
-    d->mData.push_back(newEntry);
-    if (audioTrack.isValid()) {
-        d->mTrackData.push_back(audioTrack);
-    } else {
-        d->mTrackData.push_back({});
-    }
-    endInsertRows();
-
-    restorePlayListPosition();
-    if (!d->mCurrentTrack.isValid()) {
-        resetCurrentTrack();
-    }
-
-    Q_EMIT tracksCountChanged();
-    Q_EMIT persistentStateChanged();
-
-    if (!newEntry.mIsValid) {
-        if (newEntry.mTrackUrl.isValid()) {
-            qDebug() << "MediaPlayList::enqueue" << "newTrackByFileNameInList" << newEntry.mTrackUrl;
-            if (newEntry.mTrackUrl.isLocalFile()) {
-                QFileInfo newTrackFile(newEntry.mTrackUrl.toLocalFile());
-                if (newTrackFile.exists()) {
-                    d->mData.last().mIsValid = true;
-                }
-                Q_EMIT newTrackByFileNameInList(newEntry.mTrackUrl);
-            }
-        } else {
-            Q_EMIT newTrackByNameInList(newEntry.mTitle, newEntry.mArtist, newEntry.mAlbum, newEntry.mTrackNumber, newEntry.mDiscNumber);
-        }
-    } else {
-        Q_EMIT newTrackByIdInList(newEntry.mId);
-    }
-
-    Q_EMIT trackHasBeenAdded(data(index(d->mData.size() - 1, 0), ColumnsRoles::TitleRole).toString(), data(index(d->mData.size() - 1, 0), ColumnsRoles::ImageRole).toUrl());
-
-    if (!newEntry.mIsValid) {
-        Q_EMIT dataChanged(index(rowCount() - 1, 0), index(rowCount() - 1, 0), {MediaPlayList::HasAlbumHeader});
-
-        if (!d->mCurrentTrack.isValid()) {
-            resetCurrentTrack();
-        }
-    }
-}
-
 bool MediaPlayList::moveRows(const QModelIndex &sourceParent, int sourceRow, int count, const QModelIndex &destinationParent, int destinationChild)
 {
     if (sourceParent != destinationParent) {
@@ -586,6 +522,63 @@ void MediaPlayList::move(int from, int to, int n)
     }
 }
 
+void MediaPlayList::enqueue(qulonglong newTrackId)
+{
+    enqueue(MediaPlayListEntry(newTrackId));
+}
+
+void MediaPlayList::enqueue(const MusicAudioTrack &newTrack)
+{
+    enqueue(MediaPlayListEntry(newTrack), newTrack);
+}
+
+void MediaPlayList::enqueue(const MediaPlayListEntry &newEntry, const MusicAudioTrack &audioTrack)
+{
+    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size());
+    d->mData.push_back(newEntry);
+    if (audioTrack.isValid()) {
+        d->mTrackData.push_back(audioTrack);
+    } else {
+        d->mTrackData.push_back({});
+    }
+    endInsertRows();
+
+    restorePlayListPosition();
+    if (!d->mCurrentTrack.isValid()) {
+        resetCurrentTrack();
+    }
+
+    Q_EMIT tracksCountChanged();
+    Q_EMIT persistentStateChanged();
+
+    if (!newEntry.mIsValid) {
+        if (newEntry.mTrackUrl.isValid()) {
+            qDebug() << "MediaPlayList::enqueue" << "newTrackByFileNameInList" << newEntry.mTrackUrl;
+            if (newEntry.mTrackUrl.isLocalFile()) {
+                QFileInfo newTrackFile(newEntry.mTrackUrl.toLocalFile());
+                if (newTrackFile.exists()) {
+                    d->mData.last().mIsValid = true;
+                }
+                Q_EMIT newTrackByFileNameInList(newEntry.mTrackUrl);
+            }
+        } else {
+            Q_EMIT newTrackByNameInList(newEntry.mTitle, newEntry.mArtist, newEntry.mAlbum, newEntry.mTrackNumber, newEntry.mDiscNumber);
+        }
+    } else {
+        Q_EMIT newTrackByIdInList(newEntry.mId);
+    }
+
+    Q_EMIT trackHasBeenAdded(data(index(d->mData.size() - 1, 0), ColumnsRoles::TitleRole).toString(), data(index(d->mData.size() - 1, 0), ColumnsRoles::ImageRole).toUrl());
+
+    if (!newEntry.mIsValid) {
+        Q_EMIT dataChanged(index(rowCount() - 1, 0), index(rowCount() - 1, 0), {MediaPlayList::HasAlbumHeader});
+
+        if (!d->mCurrentTrack.isValid()) {
+            resetCurrentTrack();
+        }
+    }
+}
+
 void MediaPlayList::enqueue(const MusicAlbum &album)
 {
     for (auto oneTrackIndex = 0; oneTrackIndex < album.tracksCount(); ++oneTrackIndex) {
@@ -629,27 +622,192 @@ void MediaPlayList::enqueue(const QStringList &files)
     }
 }
 
-void MediaPlayList::clearAndEnqueue(const MusicAlbum &album)
+void MediaPlayList::enqueueAndPlay(const QStringList &files)
+{
+    if (files.size() > 0) {
+        int previousTrackNumber = tracksCount();
+        enqueue(files);
+        switchTo(previousTrackNumber);
+        Q_EMIT ensurePlay();
+    }
+}
+
+void MediaPlayList::enqueue(const QList<qulonglong> &newTrackIds)
+{
+    if (newTrackIds.isEmpty()) {
+        return;
+    }
+
+    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + newTrackIds.size() - 1);
+    for (auto newTrackId : newTrackIds) {
+        d->mData.push_back(MediaPlayListEntry{newTrackId});
+        d->mTrackData.push_back({});
+        Q_EMIT newTrackByIdInList(newTrackId);
+    }
+    endInsertRows();
+
+    restorePlayListPosition();
+    if (!d->mCurrentTrack.isValid()) {
+        resetCurrentTrack();
+    }
+
+    Q_EMIT tracksCountChanged();
+    Q_EMIT persistentStateChanged();
+
+    Q_EMIT dataChanged(index(rowCount() - 1, 0), index(rowCount() - 1, 0), {MediaPlayList::HasAlbumHeader});
+}
+
+void MediaPlayList::enqueue(const QList<MusicAlbum> &albums,
+                            ElisaUtils::PlayListEnqueueMode enqueueMode,
+                            ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay)
+{
+    if (albums.isEmpty()) {
+        return;
+    }
+
+    auto tracksCount = 0;
+    for (const auto &oneAlbum : albums) {
+        for (auto oneTrackIndex = 0; oneTrackIndex < oneAlbum.tracksCount(); ++oneTrackIndex) {
+            ++tracksCount;
+        }
+    }
+
+    if (enqueueMode == ElisaUtils::ReplacePlayList) {
+        clearPlayList();
+    }
+
+    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + tracksCount - 1);
+    for (const auto &oneAlbum : albums) {
+        for (auto oneTrackIndex = 0; oneTrackIndex < oneAlbum.tracksCount(); ++oneTrackIndex) {
+            const auto &oneTrack = oneAlbum.trackFromIndex(oneTrackIndex);
+            d->mData.push_back(MediaPlayListEntry{oneTrack.databaseId()});
+            d->mTrackData.push_back(oneTrack);
+        }
+    }
+    endInsertRows();
+
+    restorePlayListPosition();
+    if (!d->mCurrentTrack.isValid()) {
+        resetCurrentTrack();
+    }
+
+    Q_EMIT tracksCountChanged();
+    Q_EMIT persistentStateChanged();
+
+    Q_EMIT dataChanged(index(rowCount() - 1, 0), index(rowCount() - 1, 0), {MediaPlayList::HasAlbumHeader});
+
+    if (triggerPlay == ElisaUtils::TriggerPlay) {
+        Q_EMIT ensurePlay();
+    }
+}
+
+void MediaPlayList::enqueue(const QList<MusicAudioTrack> &tracks,
+                            ElisaUtils::PlayListEnqueueMode enqueueMode,
+                            ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay)
+{
+    if (tracks.isEmpty()) {
+        return;
+    }
+
+    if (enqueueMode == ElisaUtils::ReplacePlayList) {
+        clearPlayList();
+    }
+
+    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + tracks.size() - 1);
+    for (const auto &oneTrack : tracks) {
+        d->mData.push_back(MediaPlayListEntry{oneTrack.databaseId()});
+        d->mTrackData.push_back(oneTrack);
+    }
+    endInsertRows();
+
+    restorePlayListPosition();
+    if (!d->mCurrentTrack.isValid()) {
+        resetCurrentTrack();
+    }
+
+    Q_EMIT tracksCountChanged();
+    Q_EMIT persistentStateChanged();
+
+    Q_EMIT dataChanged(index(rowCount() - 1, 0), index(rowCount() - 1, 0), {MediaPlayList::HasAlbumHeader});
+
+    if (triggerPlay == ElisaUtils::TriggerPlay) {
+        Q_EMIT ensurePlay();
+    }
+}
+
+void MediaPlayList::enqueueArtists(const QList<QString> &artistNames,
+                                   ElisaUtils::PlayListEnqueueMode enqueueMode,
+                                   ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay)
+{
+    if (artistNames.isEmpty()) {
+        return;
+    }
+
+    if (enqueueMode == ElisaUtils::ReplacePlayList) {
+        clearPlayList();
+    }
+
+    beginInsertRows(QModelIndex(), d->mData.size(), d->mData.size() + artistNames.size() - 1);
+    for (const auto &artistName : artistNames) {
+        d->mData.push_back(MediaPlayListEntry{artistName});
+        d->mTrackData.push_back({});
+        Q_EMIT newArtistInList(artistName);
+    }
+    endInsertRows();
+
+    restorePlayListPosition();
+    if (!d->mCurrentTrack.isValid()) {
+        resetCurrentTrack();
+    }
+
+    Q_EMIT tracksCountChanged();
+    Q_EMIT persistentStateChanged();
+
+    if (triggerPlay == ElisaUtils::TriggerPlay) {
+        Q_EMIT ensurePlay();
+    }
+}
+
+  void MediaPlayList::replaceAndPlay(qulonglong newTrackId)
+{
+    clearPlayList();
+    enqueue(MediaPlayListEntry(newTrackId));
+    Q_EMIT ensurePlay();
+}
+
+void MediaPlayList::replaceAndPlay(const MusicAudioTrack &newTrack)
+{
+    clearPlayList();
+    enqueue(newTrack);
+    Q_EMIT ensurePlay();
+}
+
+void MediaPlayList::replaceAndPlay(const MusicAlbum &album)
 {
     clearPlayList();
     enqueue(album);
+    Q_EMIT ensurePlay();
 }
 
-void MediaPlayList::clearAndEnqueue(const MusicArtist &artist)
+void MediaPlayList::replaceAndPlay(const MusicArtist &artist)
 {
-    clearAndEnqueue(artist.name());
+    clearPlayList();
+    enqueue(artist.name());
+    Q_EMIT ensurePlay();
 }
 
-void MediaPlayList::clearAndEnqueue(const QString &artistName)
+void MediaPlayList::replaceAndPlay(const QString &artistName)
 {
     clearPlayList();
     enqueue(artistName);
+    Q_EMIT ensurePlay();
 }
 
-void MediaPlayList::clearAndEnqueue(const QUrl &fileName)
+void MediaPlayList::replaceAndPlay(const QUrl &fileName)
 {
     clearPlayList();
     enqueue(fileName);
+    Q_EMIT ensurePlay();
 }
 
 void MediaPlayList::clearPlayList()
@@ -663,6 +821,10 @@ void MediaPlayList::clearPlayList()
     d->mTrackData.clear();
     endRemoveRows();
 
+    d->mCurrentPlayListPosition = 0;
+    d->mCurrentTrack = QPersistentModelIndex{};
+    notifyCurrentTrackChanged();
+
     Q_EMIT tracksCountChanged();
 }
 
