@@ -23,6 +23,7 @@
 #include "musicaudiotrack.h"
 #include "musicalbum.h"
 #include "musicartist.h"
+#include "elisautils.h"
 
 #include <QAbstractListModel>
 #include <QVector>
@@ -182,6 +183,8 @@ Q_SIGNALS:
 
     void playListLoadFailed();
 
+    void ensurePlay();
+
 public Q_SLOTS:
 
     void setPersistentState(const QVariantMap &persistentState);
@@ -226,17 +229,33 @@ public Q_SLOTS:
 
     void enqueue(const QStringList &files);
 
-    void clearAndEnqueue(qulonglong newTrackId);
+    void enqueue(const QList<qulonglong> &newTrackId);
 
-    void clearAndEnqueue(const MusicAudioTrack &newTrack);
+    void enqueue(const QList<MusicAlbum> &albums,
+                 ElisaUtils::PlayListEnqueueMode enqueueMode,
+                 ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
-    void clearAndEnqueue(const MusicAlbum &album);
+    void enqueue(const QList<MusicAudioTrack> &tracks,
+                 ElisaUtils::PlayListEnqueueMode enqueueMode,
+                 ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
-    void clearAndEnqueue(const MusicArtist &artist);
+    void enqueueArtists(const QList<QString> &artistName,
+                        ElisaUtils::PlayListEnqueueMode enqueueMode,
+                        ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
-    void clearAndEnqueue(const QString &artistName);
+    void enqueueAndPlay(const QStringList &files);
 
-    void clearAndEnqueue(const QUrl &fileName);
+    void replaceAndPlay(qulonglong newTrackId);
+
+    void replaceAndPlay(const MusicAudioTrack &newTrack);
+
+    void replaceAndPlay(const MusicAlbum &album);
+
+    void replaceAndPlay(const MusicArtist &artist);
+
+    void replaceAndPlay(const QString &artistName);
+
+    void replaceAndPlay(const QUrl &fileName);
 
     void trackInError(QUrl sourceInError, QMediaPlayer::Error playerError);
 
