@@ -67,6 +67,9 @@ MediaPlayer2Player::MediaPlayer2Player(MediaPlayList *playListControler, ManageA
     connect(m_audioPlayer, &AudioWrapper::volumeChanged,
             this, &MediaPlayer2Player::playerVolumeChanged);
 
+    m_volume = m_audioPlayer->volume();
+    signalPropertiesChange(QStringLiteral("Volume"), Volume());
+
     m_mediaPlayerPresent = 1;
 }
 
@@ -123,13 +126,13 @@ void MediaPlayer2Player::Previous()
 
 bool MediaPlayer2Player::CanPause() const
 {
-    return !m_canPlay;
+    return m_canPlay;
 }
 
 void MediaPlayer2Player::Pause()
 {
     if (m_playListControler) {
-        m_manageAudioPlayer->playPause();
+        m_manageAudioPlayer->playerPause();
     }
 }
 
@@ -155,7 +158,7 @@ bool MediaPlayer2Player::CanPlay() const
 void MediaPlayer2Player::Play()
 {
     if (m_playListControler) {
-        m_manageAudioPlayer->playPause();
+        m_manageAudioPlayer->ensurePlay();
     }
 }
 
