@@ -37,9 +37,16 @@
 #include "notificationitem.h"
 #include "elisaapplication.h"
 #include "elisa_settings.h"
-#include "allalbumsmodel.h"
-#include "allartistsmodel.h"
-#include "alltracksmodel.h"
+#include "models/allalbumsmodel.h"
+#include "models/allartistsmodel.h"
+#include "models/alltracksmodel.h"
+#include "models/albummodel.h"
+#include "models/abstractmediaproxymodel.h"
+#include "models/allalbumsproxymodel.h"
+#include "models/allartistsproxymodel.h"
+#include "models/alltracksproxymodel.h"
+#include "models/singleartistproxymodel.h"
+#include "models/singlealbumproxymodel.h"
 
 #include <KI18n/KLocalizedString>
 
@@ -95,6 +102,8 @@ public:
 
     AllTracksModel mAllTracksModel;
 
+    AlbumModel mAlbumModel;
+
     bool mIndexerBusy = false;
 
 };
@@ -123,8 +132,6 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
 
     connect(&d->mDatabaseInterface, &DatabaseInterface::artistAdded,
             this, &MusicListenersManager::artistAdded);
-    connect(&d->mDatabaseInterface, &DatabaseInterface::albumAdded,
-            this, &MusicListenersManager::albumAdded);
     connect(&d->mDatabaseInterface, &DatabaseInterface::trackAdded,
             this, &MusicListenersManager::trackAdded);
     connect(&d->mDatabaseInterface, &DatabaseInterface::tracksAdded,
@@ -167,8 +174,8 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
     d->mAllAlbumsModel.setAllArtists(&d->mAllArtistsModel);
     d->mAllArtistsModel.setAllAlbums(&d->mAllAlbumsModel);
 
-    connect(&d->mDatabaseInterface, &DatabaseInterface::albumAdded,
-            &d->mAllAlbumsModel, &AllAlbumsModel::albumAdded);
+    connect(&d->mDatabaseInterface, &DatabaseInterface::albumsAdded,
+            &d->mAllAlbumsModel, &AllAlbumsModel::albumsAdded);
     connect(&d->mDatabaseInterface, &DatabaseInterface::albumModified,
             &d->mAllAlbumsModel, &AllAlbumsModel::albumModified);
     connect(&d->mDatabaseInterface, &DatabaseInterface::albumRemoved,
@@ -187,6 +194,15 @@ MusicListenersManager::MusicListenersManager(QObject *parent)
             &d->mAllTracksModel, &AllTracksModel::trackModified);
     connect(&d->mDatabaseInterface, &DatabaseInterface::trackRemoved,
             &d->mAllTracksModel, &AllTracksModel::trackRemoved);
+
+    connect(&d->mDatabaseInterface, &DatabaseInterface::albumModified,
+            &d->mAlbumModel, &AlbumModel::albumModified);
+    connect(&d->mDatabaseInterface, &DatabaseInterface::albumRemoved,
+            &d->mAlbumModel, &AlbumModel::albumRemoved);
+    connect(&d->mAlbumModel, &AlbumModel::requestAlbumData,
+            &d->mDatabaseInterface, &DatabaseInterface::getAlbumFromAlbumId);
+    connect(&d->mDatabaseInterface, &DatabaseInterface::sentAlbumData,
+            &d->mAlbumModel, &AlbumModel::setAlbumData);
 }
 
 MusicListenersManager::~MusicListenersManager()
@@ -202,6 +218,7 @@ void MusicListenersManager::subscribeForTracks(MediaPlayList *client)
     auto helper = new TracksListener(&d->mDatabaseInterface);
 
     helper->moveToThread(&d->mDatabaseThread);
+    connect(&d->mDatabaseThread, &QThread::finished, helper, &QObject::deleteLater);
 
     connect(this, &MusicListenersManager::trackRemoved, helper, &TracksListener::trackRemoved);
     connect(this, &MusicListenersManager::tracksAdded, helper, &TracksListener::tracksAdded);
@@ -246,6 +263,11 @@ QAbstractItemModel *MusicListenersManager::allTracksModel() const
     return &d->mAllTracksModel;
 }
 
+QAbstractItemModel *MusicListenersManager::albumModel() const
+{
+    return &d->mAlbumModel;
+}
+
 bool MusicListenersManager::indexerBusy() const
 {
     return d->mIndexerBusy;
