@@ -38,6 +38,7 @@ class MediaPlayList;
 class NotificationItem;
 class ElisaApplication;
 class QAbstractItemModel;
+class AbstractMediaProxyModel;
 
 class MusicListenersManager : public QObject
 {
@@ -63,15 +64,19 @@ class MusicListenersManager : public QObject
 
     Q_PROPERTY(QAbstractItemModel* allAlbumsModel
                READ allAlbumsModel
-               NOTIFY allAlbumsModelChanged)
+               CONSTANT)
 
     Q_PROPERTY(QAbstractItemModel* allArtistsModel
                READ allArtistsModel
-               NOTIFY allArtistsModelChanged)
+               CONSTANT)
 
     Q_PROPERTY(QAbstractItemModel* allTracksModel
                READ allTracksModel
-               NOTIFY allTracksModelChanged)
+               CONSTANT)
+
+    Q_PROPERTY(QAbstractItemModel* albumModel
+               READ albumModel
+               CONSTANT)
 
     Q_PROPERTY(bool indexerBusy
                READ indexerBusy
@@ -99,6 +104,8 @@ public:
 
     QAbstractItemModel *allTracksModel() const;
 
+    QAbstractItemModel *albumModel() const;
+
     bool indexerBusy() const;
 
 Q_SIGNALS:
@@ -107,8 +114,6 @@ Q_SIGNALS:
 
     void artistAdded(const MusicArtist &newArtist);
 
-    void albumAdded(const MusicAlbum &newAlbum);
-
     void trackAdded(qulonglong id);
 
     void tracksAdded(const QList<MusicAudioTrack> &allTracks);
@@ -141,12 +146,6 @@ Q_SIGNALS:
 
     void displayTrackError(const QString &fileName);
 
-    void allAlbumsModelChanged();
-
-    void allArtistsModelChanged();
-
-    void allTracksModelChanged();
-
     void indexerBusyChanged();
 
 public Q_SLOTS:
